==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/MachinePoolNameLeaseStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachinePoolNameLeaseStatusBuilder extends MachinePoolNameLeaseStatusFluentImpl<MachinePoolNameLeaseStatusBuilder> implements VisitableBuilder<MachinePoolNameLeaseStatus,MachinePoolNameLeaseStatusBuilder>{
  public MachinePoolNameLeaseStatusBuilder() {
    this(false);
  }
  public MachinePoolNameLeaseStatusBuilder(Boolean validationEnabled) {
    this(new MachinePoolNameLeaseStatus(), validationEnabled);
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachinePoolNameLeaseStatus(), validationEnabled);
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatusFluent<?> fluent,MachinePoolNameLeaseStatus instance) {
    this(fluent, instance, false);
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatusFluent<?> fluent,MachinePoolNameLeaseStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatus instance) {
    this(instance,false);
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachinePoolNameLeaseStatusFluent<?> fluent;
  Boolean validationEnabled;
  public MachinePoolNameLeaseStatus build() {
    MachinePoolNameLeaseStatus buildable = new MachinePoolNameLeaseStatus();
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/MachinePoolNameLeaseStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachinePoolNameLeaseStatusBuilder extends MachinePoolNameLeaseStatusFluent<MachinePoolNameLeaseStatusBuilder> implements VisitableBuilder<MachinePoolNameLeaseStatus,MachinePoolNameLeaseStatusBuilder>{
  public MachinePoolNameLeaseStatusBuilder() {
    this(false);
  }
  public MachinePoolNameLeaseStatusBuilder(Boolean validationEnabled) {
    this(new MachinePoolNameLeaseStatus(), validationEnabled);
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachinePoolNameLeaseStatus(), validationEnabled);
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatusFluent<?> fluent,MachinePoolNameLeaseStatus instance) {
    this(fluent, instance, false);
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatusFluent<?> fluent,MachinePoolNameLeaseStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new MachinePoolNameLeaseStatus());

    if (instance != null) {
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatus instance) {
    this(instance,false);
  }
  public MachinePoolNameLeaseStatusBuilder(MachinePoolNameLeaseStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new MachinePoolNameLeaseStatus());

    if (instance != null) {
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachinePoolNameLeaseStatusFluent<?> fluent;
  Boolean validationEnabled;
  public MachinePoolNameLeaseStatus build() {
    MachinePoolNameLeaseStatus buildable = new MachinePoolNameLeaseStatus();
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
